from __future__ import absolute_import, division, print_function, unicode_literals

import django_otp.views
from otp_agents.forms import OTPAuthenticationForm, OTPTokenForm


class LoginView(django_otp.views.LoginView):
    """
    This is just like :class:`django_otp.views.LoginView` except that it uses
    our agent-trust-enabled forms.

    """
    otp_authentication_form = OTPAuthenticationForm
    otp_token_form = OTPTokenForm


# Backwards compatibility.
login = LoginView.as_view()



from django.conf.urls import url
import django.contrib.auth.views

import django_otp.views
import otp_agents.views

from . import views


urlpatterns = [
    url(r'^login/$', django.contrib.auth.views.LoginView.as_view()),
    url(r'^verify/$', django_otp.views.LoginView.as_view()),
    url(r'^trust/$', otp_agents.views.LoginView.as_view()),
    url(r'^logout/$', django.contrib.auth.views.LogoutView.as_view()),

    url(r'^otp/$', views.otp_view),
    url(r'^otp2/$', views.otp_view_2),
    url(r'^otp_advised/$', views.otp_advised_view),
    url(r'^otp_advised_2/$', views.otp_advised_view_2),
    url(r'^agent/$', views.agent_view),
]



from __future__ import absolute_import, division, print_function, unicode_literals

from functools import wraps

import django_agent_trust.conf
import django_otp.conf
from django_otp.decorators import otp_required as real_otp_required


def otp_required(view=None, redirect_field_name='next', login_url=None, if_configured=False, accept_trusted_agent=False):
    """
    Similar to :func:`~django_otp.decorators.otp_required`, but with an extra
    argument.

    The default value for ``login_url`` depends on the value of
    ``accept_trusted_agent``. If ``True``, we'll use
    :setting:`AGENT_LOGIN_URL`; otherwise, we'll use :setting:`OTP_LOGIN_URL`.

    :param bool accept_trusted_agent: If ``True``, we'll accept a trusted
        agent in lieu of OTP verification. Default is ``False``.
    """
    def decorator(view_func):
        @wraps(view_func)
        def _wrapped_view(request, *args, **kwargs):
            if accept_trusted_agent and request.agent.is_trusted:
                _decorator = lambda v: v
            else:
                _login_url = login_url
                if _login_url is None:
                    _login_url = django_agent_trust.conf.settings.AGENT_LOGIN_URL if accept_trusted_agent else django_otp.conf.settings.OTP_LOGIN_URL
                _decorator = real_otp_required(redirect_field_name=redirect_field_name, login_url=_login_url, if_configured=if_configured)

            return _decorator(view_func)(request, *args, **kwargs)

        return _wrapped_view

    return decorator(view) if (view is not None) else decorator



from __future__ import absolute_import, division, print_function, unicode_literals

import django_otp.admin


class TrustedAgentAdminSite(django_otp.admin.OTPAdminSite):
    """
    This is an :class:`~django_otp.admin.OTPAdminSite` subclass that is
    satisfied by a trusted agent.

    This is identical to ``django_otp.admin.OTPAdminSite`` except that it will
    skip the login dialog if the user is already logged in and is either
    verified with an OTP device or is coming from a previously trusted agent.

    Note that :class:`~django.contrib.admin.AdminSite` lacks the hooks
    necessary to properly implement a trusted agent login form here. If the
    user does not meet the criteria above, they will have to verify themselves
    with an OTP device to log in. The experience will be better if you send
    users through your own custom login flow before redirecting them to this
    admin site.

    """
    def has_permission(self, request):
        return super(django_otp.admin.OTPAdminSite, self).has_permission(request) and \
            (request.user.is_verified() or request.agent.is_trusted)
